==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudtrail/kotlin/inputs/TrailAdvancedEventSelectorFieldSelectorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudtrail.kotlin.inputs

import com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property endsWiths A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
 * @property equals A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
 * @property field Field in an event record on which to filter events to be logged. You can specify only the following values: `readOnly`, `eventSource`, `eventName`, `eventCategory`, `resources.type`, `resources.ARN`.
 * @property notEndsWiths A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
 * @property notEquals A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
 * @property notStartsWiths A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
 * @property startsWiths A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
 */
public data class TrailAdvancedEventSelectorFieldSelectorArgs(
    public val endsWiths: Output<List<String>>? = null,
    public val equals: Output<List<String>>? = null,
    public val `field`: Output<String>,
    public val notEndsWiths: Output<List<String>>? = null,
    public val notEquals: Output<List<String>>? = null,
    public val notStartsWiths: Output<List<String>>? = null,
    public val startsWiths: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs> {
    override fun toJava():
        com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs =
        com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs.builder()
            .endsWiths(endsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .equals_(equals?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .`field`(`field`.applyValue({ args0 -> args0 }))
            .notEndsWiths(notEndsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notEquals(notEquals?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notStartsWiths(notStartsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .startsWiths(startsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [TrailAdvancedEventSelectorFieldSelectorArgs].
 */
@PulumiTagMarker
public class TrailAdvancedEventSelectorFieldSelectorArgsBuilder internal constructor() {
    private var endsWiths: Output<List<String>>? = null

    private var equals: Output<List<String>>? = null

    private var `field`: Output<String>? = null

    private var notEndsWiths: Output<List<String>>? = null

    private var notEquals: Output<List<String>>? = null

    private var notStartsWiths: Output<List<String>>? = null

    private var startsWiths: Output<List<String>>? = null

    /**
     * @param value A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("kplxvxhnyupjstex")
    public suspend fun endsWiths(`value`: Output<List<String>>) {
        this.endsWiths = value
    }

    @JvmName("pfxisbhhwfxighkp")
    public suspend fun endsWiths(vararg values: Output<String>) {
        this.endsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("jaahudgrebbigmys")
    public suspend fun endsWiths(values: List<Output<String>>) {
        this.endsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("opuggllphdhwcbxj")
    public suspend fun equals(`value`: Output<List<String>>) {
        this.equals = value
    }

    @JvmName("xtqgcmonmvjojwgl")
    public suspend fun equals(vararg values: Output<String>) {
        this.equals = Output.all(values.asList())
    }

    /**
     * @param values A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("ecqsaxryllatfwei")
    public suspend fun equals(values: List<Output<String>>) {
        this.equals = Output.all(values)
    }

    /**
     * @param value Field in an event record on which to filter events to be logged. You can specify only the following values: `readOnly`, `eventSource`, `eventName`, `eventCategory`, `resources.type`, `resources.ARN`.
     */
    @JvmName("ubomlwlxmveuqsyo")
    public suspend fun `field`(`value`: Output<String>) {
        this.`field` = value
    }

    /**
     * @param value A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("qhsernqbfkqtaxad")
    public suspend fun notEndsWiths(`value`: Output<List<String>>) {
        this.notEndsWiths = value
    }

    @JvmName("jpnboisqmeqsbxcn")
    public suspend fun notEndsWiths(vararg values: Output<String>) {
        this.notEndsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("moectjxaodpelsin")
    public suspend fun notEndsWiths(values: List<Output<String>>) {
        this.notEndsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("uujkureflloycnoe")
    public suspend fun notEquals(`value`: Output<List<String>>) {
        this.notEquals = value
    }

    @JvmName("siynmjlxwtlnhdts")
    public suspend fun notEquals(vararg values: Output<String>) {
        this.notEquals = Output.all(values.asList())
    }

    /**
     * @param values A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("tnljqhvdaawylerc")
    public suspend fun notEquals(values: List<Output<String>>) {
        this.notEquals = Output.all(values)
    }

    /**
     * @param value A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("lckwclswqrfvwfbq")
    public suspend fun notStartsWiths(`value`: Output<List<String>>) {
        this.notStartsWiths = value
    }

    @JvmName("ofqmtjpuidicoqjp")
    public suspend fun notStartsWiths(vararg values: Output<String>) {
        this.notStartsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("nvecupattufocnsx")
    public suspend fun notStartsWiths(values: List<Output<String>>) {
        this.notStartsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("nmovfiktvwycyrwx")
    public suspend fun startsWiths(`value`: Output<List<String>>) {
        this.startsWiths = value
    }

    @JvmName("ggaewvjgbpndwksw")
    public suspend fun startsWiths(vararg values: Output<String>) {
        this.startsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("cespfevvubpwyixa")
    public suspend fun startsWiths(values: List<Output<String>>) {
        this.startsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("eixgjlvdqfvpbcpp")
    public suspend fun endsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endsWiths = mapped
    }

    /**
     * @param values A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("pmiyvlpgakebrjqm")
    public suspend fun endsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endsWiths = mapped
    }

    /**
     * @param value A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("xdipjcdqsodnwlow")
    public suspend fun equals(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.equals = mapped
    }

    /**
     * @param values A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("cskmxwdbmogjgdfh")
    public suspend fun equals(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.equals = mapped
    }

    /**
     * @param value Field in an event record on which to filter events to be logged. You can specify only the following values: `readOnly`, `eventSource`, `eventName`, `eventCategory`, `resources.type`, `resources.ARN`.
     */
    @JvmName("cvbtccbcbyqbbtgt")
    public suspend fun `field`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`field` = mapped
    }

    /**
     * @param value A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("hvevqyytgfhelyjf")
    public suspend fun notEndsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notEndsWiths = mapped
    }

    /**
     * @param values A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("solxtndnhqnbpijp")
    public suspend fun notEndsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notEndsWiths = mapped
    }

    /**
     * @param value A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("hmavnjtpumxyuhtn")
    public suspend fun notEquals(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notEquals = mapped
    }

    /**
     * @param values A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("qprhomnfdyasxatx")
    public suspend fun notEquals(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notEquals = mapped
    }

    /**
     * @param value A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("ippqaapejplkgrfh")
    public suspend fun notStartsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notStartsWiths = mapped
    }

    /**
     * @param values A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("vqktesebuqareqwr")
    public suspend fun notStartsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notStartsWiths = mapped
    }

    /**
     * @param value A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("btfubtvaknibkpln")
    public suspend fun startsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startsWiths = mapped
    }

    /**
     * @param values A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("kqvrfhslaynrtxio")
    public suspend fun startsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.startsWiths = mapped
    }

    internal fun build(): TrailAdvancedEventSelectorFieldSelectorArgs =
        TrailAdvancedEventSelectorFieldSelectorArgs(
            endsWiths = endsWiths,
            equals = equals,
            `field` = `field` ?: throw PulumiNullFieldException("field"),
            notEndsWiths = notEndsWiths,
            notEquals = notEquals,
            notStartsWiths = notStartsWiths,
            startsWiths = startsWiths,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudtrail/kotlin/inputs/TrailAdvancedEventSelectorFieldSelectorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudtrail.kotlin.inputs

import com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property endsWiths A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
 * @property equals A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
 * @property field Field in an event record on which to filter events to be logged. You can specify only the following values: `readOnly`, `eventSource`, `eventName`, `eventCategory`, `resources.type`, `resources.ARN`.
 * @property notEndsWiths A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
 * @property notEquals A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
 * @property notStartsWiths A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
 * @property startsWiths A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
 */
public data class TrailAdvancedEventSelectorFieldSelectorArgs(
    public val endsWiths: Output<List<String>>? = null,
    public val equals: Output<List<String>>? = null,
    public val `field`: Output<String>,
    public val notEndsWiths: Output<List<String>>? = null,
    public val notEquals: Output<List<String>>? = null,
    public val notStartsWiths: Output<List<String>>? = null,
    public val startsWiths: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs> {
    override fun toJava(): com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs =
        com.pulumi.aws.cloudtrail.inputs.TrailAdvancedEventSelectorFieldSelectorArgs.builder()
            .endsWiths(endsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .equals_(equals?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .`field`(`field`.applyValue({ args0 -> args0 }))
            .notEndsWiths(notEndsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notEquals(notEquals?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .notStartsWiths(notStartsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .startsWiths(startsWiths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [TrailAdvancedEventSelectorFieldSelectorArgs].
 */
@PulumiTagMarker
public class TrailAdvancedEventSelectorFieldSelectorArgsBuilder internal constructor() {
    private var endsWiths: Output<List<String>>? = null

    private var equals: Output<List<String>>? = null

    private var `field`: Output<String>? = null

    private var notEndsWiths: Output<List<String>>? = null

    private var notEquals: Output<List<String>>? = null

    private var notStartsWiths: Output<List<String>>? = null

    private var startsWiths: Output<List<String>>? = null

    /**
     * @param value A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("xqpyentewqchmxaa")
    public suspend fun endsWiths(`value`: Output<List<String>>) {
        this.endsWiths = value
    }

    @JvmName("twgtdlvcjjmnxrfm")
    public suspend fun endsWiths(vararg values: Output<String>) {
        this.endsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("ybtdhmqwmfoipsqt")
    public suspend fun endsWiths(values: List<Output<String>>) {
        this.endsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("djfdpomapdcagjen")
    public suspend fun equals(`value`: Output<List<String>>) {
        this.equals = value
    }

    @JvmName("ffffsidhpmvvbxfr")
    public suspend fun equals(vararg values: Output<String>) {
        this.equals = Output.all(values.asList())
    }

    /**
     * @param values A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("fxguqcwgiefshldi")
    public suspend fun equals(values: List<Output<String>>) {
        this.equals = Output.all(values)
    }

    /**
     * @param value Field in an event record on which to filter events to be logged. You can specify only the following values: `readOnly`, `eventSource`, `eventName`, `eventCategory`, `resources.type`, `resources.ARN`.
     */
    @JvmName("ljqvqprjnhekokph")
    public suspend fun `field`(`value`: Output<String>) {
        this.`field` = value
    }

    /**
     * @param value A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("juyybqdbmxavojyw")
    public suspend fun notEndsWiths(`value`: Output<List<String>>) {
        this.notEndsWiths = value
    }

    @JvmName("xurnomhvguuvyoue")
    public suspend fun notEndsWiths(vararg values: Output<String>) {
        this.notEndsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("mqgxedhulxdxotxn")
    public suspend fun notEndsWiths(values: List<Output<String>>) {
        this.notEndsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("yveswocovmtiiiae")
    public suspend fun notEquals(`value`: Output<List<String>>) {
        this.notEquals = value
    }

    @JvmName("yhqwhisveocsveys")
    public suspend fun notEquals(vararg values: Output<String>) {
        this.notEquals = Output.all(values.asList())
    }

    /**
     * @param values A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("llicjtnlkjoffxqv")
    public suspend fun notEquals(values: List<Output<String>>) {
        this.notEquals = Output.all(values)
    }

    /**
     * @param value A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("gqlkfjospltjpbbl")
    public suspend fun notStartsWiths(`value`: Output<List<String>>) {
        this.notStartsWiths = value
    }

    @JvmName("ttypektsgiikjsas")
    public suspend fun notStartsWiths(vararg values: Output<String>) {
        this.notStartsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("odinxqaaldfaokid")
    public suspend fun notStartsWiths(values: List<Output<String>>) {
        this.notStartsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("rpavpoqjvyvbxlic")
    public suspend fun startsWiths(`value`: Output<List<String>>) {
        this.startsWiths = value
    }

    @JvmName("ohibghikobsjwbmr")
    public suspend fun startsWiths(vararg values: Output<String>) {
        this.startsWiths = Output.all(values.asList())
    }

    /**
     * @param values A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("vexvbcmqhrkjoygw")
    public suspend fun startsWiths(values: List<Output<String>>) {
        this.startsWiths = Output.all(values)
    }

    /**
     * @param value A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("wvnjessdcpkiegbe")
    public suspend fun endsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endsWiths = mapped
    }

    /**
     * @param values A list of values that includes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("vrnpndaxgxvsoger")
    public suspend fun endsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endsWiths = mapped
    }

    /**
     * @param value A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("yklutnfxcgcxigcv")
    public suspend fun equals(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.equals = mapped
    }

    /**
     * @param values A list of values that includes events that match the exact value of the event record field specified as the value of `field`. This is the only valid operator that you can use with the `readOnly`, `eventCategory`, and `resources.type` fields.
     */
    @JvmName("llabfaejcknsbfdw")
    public suspend fun equals(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.equals = mapped
    }

    /**
     * @param value Field in an event record on which to filter events to be logged. You can specify only the following values: `readOnly`, `eventSource`, `eventName`, `eventCategory`, `resources.type`, `resources.ARN`.
     */
    @JvmName("xnmvbnkllpcmudsv")
    public suspend fun `field`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`field` = mapped
    }

    /**
     * @param value A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("fxscmrjodekwbomf")
    public suspend fun notEndsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notEndsWiths = mapped
    }

    /**
     * @param values A list of values that excludes events that match the last few characters of the event record field specified as the value of `field`.
     */
    @JvmName("tjdarlgkhufeqenu")
    public suspend fun notEndsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notEndsWiths = mapped
    }

    /**
     * @param value A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("xotkbftjdavfjecc")
    public suspend fun notEquals(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notEquals = mapped
    }

    /**
     * @param values A list of values that excludes events that match the exact value of the event record field specified as the value of `field`.
     */
    @JvmName("irjwgmduuuogfhnf")
    public suspend fun notEquals(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notEquals = mapped
    }

    /**
     * @param value A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("vpbuwtcxegdxumbh")
    public suspend fun notStartsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notStartsWiths = mapped
    }

    /**
     * @param values A list of values that excludes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("ygefnqpvlfbmgxif")
    public suspend fun notStartsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notStartsWiths = mapped
    }

    /**
     * @param value A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("erueehexonrrgsxs")
    public suspend fun startsWiths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startsWiths = mapped
    }

    /**
     * @param values A list of values that includes events that match the first few characters of the event record field specified as the value of `field`.
     */
    @JvmName("uofcuxeeydbtrjmr")
    public suspend fun startsWiths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.startsWiths = mapped
    }

    internal fun build(): TrailAdvancedEventSelectorFieldSelectorArgs =
        TrailAdvancedEventSelectorFieldSelectorArgs(
            endsWiths = endsWiths,
            equals = equals,
            `field` = `field` ?: throw PulumiNullFieldException("field"),
            notEndsWiths = notEndsWiths,
            notEquals = notEquals,
            notStartsWiths = notStartsWiths,
            startsWiths = startsWiths,
        )
}
